Exception: MailAuth::Spf::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/mailauth/spf.rb

Overview

Results check_host() reaches without any mechanism matching. Travel as exceptions because they can happen several includes deep and end the whole evaluation, not just the record where they were found.

Direct Known Subclasses

NoRecord, PermError, TempError

Instance Method Summary collapse

Instance Method Details

#statusObject



26
27
28
# File 'lib/mailauth/spf.rb', line 26

def status
  Status::TEMPERROR
end