Exception: MailAuth::Spf::Error
- Inherits:
-
StandardError
- Object
- StandardError
- MailAuth::Spf::Error
- Defined in:
- lib/mailauth/spf.rb
Overview
Results check_host() reaches without any mechanism matching. Travel as
exceptions because they can happen several includes deep and end the
whole evaluation, not just the record where they were found.